pub struct FormulaGraph { /* private fields */ }Implementations
Sourceimpl FormulaGraph
impl FormulaGraph
pub fn build(sheet: &Worksheet, atlas: &FormulaAtlas) -> Result<Self>
pub fn groups(&self) -> Vec<FormulaGroup>
pub fn precedents(&self, address: &str) -> Vec<String>
pub fn dependents(&self, address: &str) -> Vec<String>
Sourcepub fn dependents_limited(
&self,
address: &str,
limit: Option<usize>,
) -> (Vec<String>, bool)
pub fn dependents_limited( &self, address: &str, limit: Option<usize>, ) -> (Vec<String>, bool)
Returns cells that depend on the given address, with optional limit.
Returns (dependents, was_truncated). If limit is Some and exceeded, was_truncated is true and only limit dependents are returned.
Performance: O(n) where n = number of large range references in the sheet. Early exits when limit reached to keep response times bounded.