pub struct SessionStore { /* private fields */ }Expand description
Persistent session store managing .asp/sessions/ directories.
Implementations
Sourceimpl SessionStore
impl SessionStore
Sourcepub fn open(workspace_root: impl Into<PathBuf>) -> Result<SessionStore, Error>
pub fn open(workspace_root: impl Into<PathBuf>) -> Result<SessionStore, Error>
Open or create a session store at the given workspace root.
The .asp/sessions/ directory is created if it doesn’t exist.
Sourcepub fn create_session(
&self,
base_path: &Path,
label: Option<&str>,
) -> Result<SessionHandle, Error>
pub fn create_session( &self, base_path: &Path, label: Option<&str>, ) -> Result<SessionHandle, Error>
Create a new session from a base workbook file.
Sourcepub fn open_session(&self, session_id: &str) -> Result<SessionHandle, Error>
pub fn open_session(&self, session_id: &str) -> Result<SessionHandle, Error>
Open an existing session by ID.