pub struct CellChange {
pub sheet: String,
pub diff: CellDiff,
}Fields
sheet: Stringdiff: CellDiffTrait Implementations
Sourceimpl Debug for CellChange
impl Debug for CellChange
Sourceimpl JsonSchema for CellChange
impl JsonSchema for CellChange
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CellChange
impl RefUnwindSafe for CellChange
impl Send for CellChange
impl Sync for CellChange
impl Unpin for CellChange
impl UnwindSafe for CellChange