pub struct ChangeSummary {
pub op_kinds: Vec<String>,
pub affected_sheets: Vec<String>,
pub affected_bounds: Vec<String>,
pub counts: BTreeMap<String, u64>,
pub flags: BTreeMap<String, bool>,
pub warnings: Vec<String>,
}Fields
op_kinds: Vec<String>affected_sheets: Vec<String>affected_bounds: Vec<String>counts: BTreeMap<String, u64>flags: BTreeMap<String, bool>warnings: Vec<String>Trait Implementations
Sourceimpl Clone for ChangeSummary
impl Clone for ChangeSummary
Sourcefn clone(&self) -> ChangeSummary
fn clone(&self) -> ChangeSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChangeSummary
impl Debug for ChangeSummary
Sourceimpl Default for ChangeSummary
impl Default for ChangeSummary
Sourcefn default() -> ChangeSummary
fn default() -> ChangeSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ChangeSummary
impl<'de> Deserialize<'de> for ChangeSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChangeSummary
impl JsonSchema for ChangeSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChangeSummary
impl RefUnwindSafe for ChangeSummary
impl Send for ChangeSummary
impl Sync for ChangeSummary
impl Unpin for ChangeSummary
impl UnwindSafe for ChangeSummary