pub struct AlignmentDescriptor {
pub horizontal: Option<String>,
pub vertical: Option<String>,
pub wrap_text: Option<bool>,
pub text_rotation: Option<u32>,
}Fields
horizontal: Option<String>vertical: Option<String>wrap_text: Option<bool>text_rotation: Option<u32>Trait Implementations
Sourceimpl Clone for AlignmentDescriptor
impl Clone for AlignmentDescriptor
Sourcefn clone(&self) -> AlignmentDescriptor
fn clone(&self) -> AlignmentDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlignmentDescriptor
impl Debug for AlignmentDescriptor
Sourceimpl Default for AlignmentDescriptor
impl Default for AlignmentDescriptor
Sourcefn default() -> AlignmentDescriptor
fn default() -> AlignmentDescriptor
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AlignmentDescriptor
impl<'de> Deserialize<'de> for AlignmentDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AlignmentDescriptor
impl JsonSchema for AlignmentDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AlignmentDescriptor
impl RefUnwindSafe for AlignmentDescriptor
impl Send for AlignmentDescriptor
impl Sync for AlignmentDescriptor
impl Unpin for AlignmentDescriptor
impl UnwindSafe for AlignmentDescriptor