pub struct BordersPatch {
pub left: Option<Option<BorderSidePatch>>,
pub right: Option<Option<BorderSidePatch>>,
pub top: Option<Option<BorderSidePatch>>,
pub bottom: Option<Option<BorderSidePatch>>,
pub diagonal: Option<Option<BorderSidePatch>>,
pub vertical: Option<Option<BorderSidePatch>>,
pub horizontal: Option<Option<BorderSidePatch>>,
pub diagonal_up: Option<Option<bool>>,
pub diagonal_down: Option<Option<bool>>,
}Fields
left: Option<Option<BorderSidePatch>>right: Option<Option<BorderSidePatch>>top: Option<Option<BorderSidePatch>>bottom: Option<Option<BorderSidePatch>>diagonal: Option<Option<BorderSidePatch>>vertical: Option<Option<BorderSidePatch>>horizontal: Option<Option<BorderSidePatch>>diagonal_up: Option<Option<bool>>diagonal_down: Option<Option<bool>>Trait Implementations
Sourceimpl Clone for BordersPatch
impl Clone for BordersPatch
Sourcefn clone(&self) -> BordersPatch
fn clone(&self) -> BordersPatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BordersPatch
impl Debug for BordersPatch
Sourceimpl Default for BordersPatch
impl Default for BordersPatch
Sourcefn default() -> BordersPatch
fn default() -> BordersPatch
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BordersPatch
impl<'de> Deserialize<'de> for BordersPatch
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BordersPatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BordersPatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BordersPatch
impl JsonSchema for BordersPatch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BordersPatch
impl Serialize for BordersPatch
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more