pub struct DefineNameResponse {
pub workbook_id: WorkbookId,
pub name: String,
pub refers_to: String,
pub scope_kind: NamedRangeScope,
pub scope_sheet_name: Option<String>,
}Fields
workbook_id: WorkbookIdname: Stringrefers_to: Stringscope_kind: NamedRangeScopescope_sheet_name: Option<String>Trait Implementations
Sourceimpl Clone for DefineNameResponse
impl Clone for DefineNameResponse
Sourcefn clone(&self) -> DefineNameResponse
fn clone(&self) -> DefineNameResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefineNameResponse
impl Debug for DefineNameResponse
Sourceimpl<'de> Deserialize<'de> for DefineNameResponse
impl<'de> Deserialize<'de> for DefineNameResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DefineNameResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DefineNameResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DefineNameResponse
impl JsonSchema for DefineNameResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DefineNameResponse
impl Serialize for DefineNameResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more