pub struct FormulaParseDiagnostics {
pub policy: FormulaParsePolicy,
pub total_errors: usize,
pub groups_truncated: bool,
pub groups: Vec<FormulaParseErrorGroup>,
}Fields
policy: FormulaParsePolicytotal_errors: usizegroups_truncated: boolgroups: Vec<FormulaParseErrorGroup>Trait Implementations
Sourceimpl Clone for FormulaParseDiagnostics
impl Clone for FormulaParseDiagnostics
Sourcefn clone(&self) -> FormulaParseDiagnostics
fn clone(&self) -> FormulaParseDiagnostics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormulaParseDiagnostics
impl Debug for FormulaParseDiagnostics
Sourceimpl<'de> Deserialize<'de> for FormulaParseDiagnostics
impl<'de> Deserialize<'de> for FormulaParseDiagnostics
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FormulaParseDiagnostics, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FormulaParseDiagnostics, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FormulaParseDiagnostics
impl JsonSchema for FormulaParseDiagnostics
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for FormulaParseDiagnostics
impl Serialize for FormulaParseDiagnostics
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more