pub struct GridColumnHint {
pub offset: u32,
pub width_chars: f64,
}Fields
offset: u32width_chars: f64Trait Implementations
Sourceimpl Clone for GridColumnHint
impl Clone for GridColumnHint
Sourcefn clone(&self) -> GridColumnHint
fn clone(&self) -> GridColumnHint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GridColumnHint
impl Debug for GridColumnHint
Sourceimpl<'de> Deserialize<'de> for GridColumnHint
impl<'de> Deserialize<'de> for GridColumnHint
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GridColumnHint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GridColumnHint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GridColumnHint
impl JsonSchema for GridColumnHint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for GridColumnHint
impl Serialize for GridColumnHint
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more