pub struct RangeValuesResponse {
pub workbook_id: WorkbookId,
pub workbook_short_id: String,
pub sheet_name: String,
pub warnings: Vec<Warning>,
pub values: Vec<RangeValuesEntry>,
}Fields
workbook_id: WorkbookIdworkbook_short_id: Stringsheet_name: Stringwarnings: Vec<Warning>values: Vec<RangeValuesEntry>Trait Implementations
Sourceimpl Clone for RangeValuesResponse
impl Clone for RangeValuesResponse
Sourcefn clone(&self) -> RangeValuesResponse
fn clone(&self) -> RangeValuesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeValuesResponse
impl Debug for RangeValuesResponse
Sourceimpl<'de> Deserialize<'de> for RangeValuesResponse
impl<'de> Deserialize<'de> for RangeValuesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RangeValuesResponse
impl JsonSchema for RangeValuesResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RangeValuesResponse
impl RefUnwindSafe for RangeValuesResponse
impl Send for RangeValuesResponse
impl Sync for RangeValuesResponse
impl Unpin for RangeValuesResponse
impl UnwindSafe for RangeValuesResponse