pub struct RegionCountSummary {
pub data: u32,
pub parameters: u32,
pub outputs: u32,
pub calculator: u32,
pub metadata: u32,
pub other: u32,
}Fields
data: u32parameters: u32outputs: u32calculator: u32metadata: u32other: u32Trait Implementations
Sourceimpl Clone for RegionCountSummary
impl Clone for RegionCountSummary
Sourcefn clone(&self) -> RegionCountSummary
fn clone(&self) -> RegionCountSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegionCountSummary
impl Debug for RegionCountSummary
Sourceimpl Default for RegionCountSummary
impl Default for RegionCountSummary
Sourcefn default() -> RegionCountSummary
fn default() -> RegionCountSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RegionCountSummary
impl<'de> Deserialize<'de> for RegionCountSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegionCountSummary
impl JsonSchema for RegionCountSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RegionCountSummary
impl RefUnwindSafe for RegionCountSummary
impl Send for RegionCountSummary
impl Sync for RegionCountSummary
impl Unpin for RegionCountSummary
impl UnwindSafe for RegionCountSummary