pub struct TraceLayerHighlights {
pub top_ranges: Vec<TraceRangeHighlight>,
pub top_formula_groups: Vec<TraceFormulaGroupHighlight>,
pub notable_cells: Vec<TraceCellHighlight>,
}Fields
top_ranges: Vec<TraceRangeHighlight>top_formula_groups: Vec<TraceFormulaGroupHighlight>notable_cells: Vec<TraceCellHighlight>Trait Implementations
Sourceimpl Clone for TraceLayerHighlights
impl Clone for TraceLayerHighlights
Sourcefn clone(&self) -> TraceLayerHighlights
fn clone(&self) -> TraceLayerHighlights
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceLayerHighlights
impl Debug for TraceLayerHighlights
Sourceimpl<'de> Deserialize<'de> for TraceLayerHighlights
impl<'de> Deserialize<'de> for TraceLayerHighlights
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceLayerHighlights, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceLayerHighlights, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceLayerHighlights
impl JsonSchema for TraceLayerHighlights
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TraceLayerHighlights
impl Serialize for TraceLayerHighlights
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more