pub struct VolatileScanEntry {
pub address: String,
pub sheet_name: String,
pub function: String,
pub note: Option<String>,
}Fields
address: Stringsheet_name: Stringfunction: Stringnote: Option<String>Trait Implementations
Sourceimpl Clone for VolatileScanEntry
impl Clone for VolatileScanEntry
Sourcefn clone(&self) -> VolatileScanEntry
fn clone(&self) -> VolatileScanEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VolatileScanEntry
impl Debug for VolatileScanEntry
Sourceimpl<'de> Deserialize<'de> for VolatileScanEntry
impl<'de> Deserialize<'de> for VolatileScanEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VolatileScanEntry
impl JsonSchema for VolatileScanEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VolatileScanEntry
impl RefUnwindSafe for VolatileScanEntry
impl Send for VolatileScanEntry
impl Sync for VolatileScanEntry
impl Unpin for VolatileScanEntry
impl UnwindSafe for VolatileScanEntry