pub struct WorkbookDescription {Show 13 fields
pub workbook_id: WorkbookId,
pub short_id: String,
pub slug: String,
pub path: String,
pub client_path: Option<String>,
pub bytes: u64,
pub sheet_count: usize,
pub defined_names: usize,
pub tables: usize,
pub macros_present: bool,
pub last_modified: Option<String>,
pub revision_id: Option<String>,
pub caps: BackendCaps,
}Fields
workbook_id: WorkbookIdshort_id: Stringslug: Stringpath: Stringclient_path: Option<String>bytes: u64sheet_count: usizedefined_names: usizetables: usizemacros_present: boollast_modified: Option<String>revision_id: Option<String>caps: BackendCapsTrait Implementations
Sourceimpl Clone for WorkbookDescription
impl Clone for WorkbookDescription
Sourcefn clone(&self) -> WorkbookDescription
fn clone(&self) -> WorkbookDescription
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkbookDescription
impl Debug for WorkbookDescription
Sourceimpl<'de> Deserialize<'de> for WorkbookDescription
impl<'de> Deserialize<'de> for WorkbookDescription
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkbookDescription
impl JsonSchema for WorkbookDescription
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkbookDescription
impl RefUnwindSafe for WorkbookDescription
impl Send for WorkbookDescription
impl Sync for WorkbookDescription
impl Unpin for WorkbookDescription
impl UnwindSafe for WorkbookDescription