pub struct ApplyFormulaPatternOpInput {
pub sheet_name: String,
pub target_range: String,
pub anchor_cell: String,
pub base_formula: String,
pub fill_direction: Option<FillDirection>,
pub relative_mode: Option<FormulaRelativeMode>,
}Fields
sheet_name: Stringtarget_range: Stringanchor_cell: Stringbase_formula: Stringfill_direction: Option<FillDirection>relative_mode: Option<FormulaRelativeMode>Trait Implementations
Sourceimpl Clone for ApplyFormulaPatternOpInput
impl Clone for ApplyFormulaPatternOpInput
Sourcefn clone(&self) -> ApplyFormulaPatternOpInput
fn clone(&self) -> ApplyFormulaPatternOpInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApplyFormulaPatternOpInput
impl Debug for ApplyFormulaPatternOpInput
Sourceimpl<'de> Deserialize<'de> for ApplyFormulaPatternOpInput
impl<'de> Deserialize<'de> for ApplyFormulaPatternOpInput
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ApplyFormulaPatternOpInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ApplyFormulaPatternOpInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ApplyFormulaPatternOpInput
impl JsonSchema for ApplyFormulaPatternOpInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApplyFormulaPatternOpInput
impl RefUnwindSafe for ApplyFormulaPatternOpInput
impl Send for ApplyFormulaPatternOpInput
impl Sync for ApplyFormulaPatternOpInput
impl Unpin for ApplyFormulaPatternOpInput
impl UnsafeUnpin for ApplyFormulaPatternOpInput
impl UnwindSafe for ApplyFormulaPatternOpInput