pub struct ApplyFormulaPatternResponse {
pub fork_id: String,
pub sheet_name: String,
pub target_range: String,
pub mode: String,
pub change_id: Option<String>,
pub cells_filled: u64,
pub summary: ChangeSummary,
}Fields
fork_id: Stringsheet_name: Stringtarget_range: Stringmode: Stringchange_id: Option<String>cells_filled: u64summary: ChangeSummaryTrait Implementations
Sourceimpl Debug for ApplyFormulaPatternResponse
impl Debug for ApplyFormulaPatternResponse
Sourceimpl JsonSchema for ApplyFormulaPatternResponse
impl JsonSchema for ApplyFormulaPatternResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApplyFormulaPatternResponse
impl RefUnwindSafe for ApplyFormulaPatternResponse
impl Send for ApplyFormulaPatternResponse
impl Sync for ApplyFormulaPatternResponse
impl Unpin for ApplyFormulaPatternResponse
impl UnwindSafe for ApplyFormulaPatternResponse