pub struct ApplyStagedChangeResponse {
pub fork_id: String,
pub change_id: String,
pub ops_applied: usize,
pub summary: ChangeSummary,
}Fields
fork_id: Stringchange_id: Stringops_applied: usizesummary: ChangeSummaryTrait Implementations
Sourceimpl Debug for ApplyStagedChangeResponse
impl Debug for ApplyStagedChangeResponse
Sourceimpl JsonSchema for ApplyStagedChangeResponse
impl JsonSchema for ApplyStagedChangeResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApplyStagedChangeResponse
impl RefUnwindSafe for ApplyStagedChangeResponse
impl Send for ApplyStagedChangeResponse
impl Sync for ApplyStagedChangeResponse
impl Unpin for ApplyStagedChangeResponse
impl UnwindSafe for ApplyStagedChangeResponse