pub struct ChangesetSummary {
pub total_changes: u32,
pub returned_changes: u32,
pub truncated: bool,
pub next_offset: Option<u32>,
pub counts_by_kind: BTreeMap<String, u32>,
pub counts_by_type: BTreeMap<String, u32>,
pub counts_by_subtype: BTreeMap<String, u32>,
pub affected_sheets: Vec<String>,
}Fields
total_changes: u32returned_changes: u32truncated: boolnext_offset: Option<u32>counts_by_kind: BTreeMap<String, u32>counts_by_type: BTreeMap<String, u32>counts_by_subtype: BTreeMap<String, u32>affected_sheets: Vec<String>Trait Implementations
Sourceimpl Debug for ChangesetSummary
impl Debug for ChangesetSummary
Sourceimpl JsonSchema for ChangesetSummary
impl JsonSchema for ChangesetSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChangesetSummary
impl RefUnwindSafe for ChangesetSummary
impl Send for ChangesetSummary
impl Sync for ChangesetSummary
impl Unpin for ChangesetSummary
impl UnwindSafe for ChangesetSummary