pub struct CheckpointForkResponse {
pub fork_id: String,
pub checkpoint: CheckpointInfo,
pub total_checkpoints: usize,
}Fields
fork_id: Stringcheckpoint: CheckpointInfototal_checkpoints: usizeTrait Implementations
Sourceimpl Debug for CheckpointForkResponse
impl Debug for CheckpointForkResponse
Sourceimpl JsonSchema for CheckpointForkResponse
impl JsonSchema for CheckpointForkResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CheckpointForkResponse
impl RefUnwindSafe for CheckpointForkResponse
impl Send for CheckpointForkResponse
impl Sync for CheckpointForkResponse
impl Unpin for CheckpointForkResponse
impl UnwindSafe for CheckpointForkResponse