pub struct CheckpointInfo {
pub checkpoint_id: String,
pub created_at: String,
pub label: Option<String>,
}Fields
checkpoint_id: Stringcreated_at: Stringlabel: Option<String>Trait Implementations
Sourceimpl Debug for CheckpointInfo
impl Debug for CheckpointInfo
Sourceimpl JsonSchema for CheckpointInfo
impl JsonSchema for CheckpointInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CheckpointInfo
impl RefUnwindSafe for CheckpointInfo
impl Send for CheckpointInfo
impl Sync for CheckpointInfo
impl Unpin for CheckpointInfo
impl UnwindSafe for CheckpointInfo