pub struct ColumnSizeBatchResponse {
pub fork_id: String,
pub sheet_name: String,
pub mode: String,
pub change_id: Option<String>,
pub ops_applied: usize,
pub summary: ChangeSummary,
}Fields
fork_id: Stringsheet_name: Stringmode: Stringchange_id: Option<String>ops_applied: usizesummary: ChangeSummaryTrait Implementations
Sourceimpl Debug for ColumnSizeBatchResponse
impl Debug for ColumnSizeBatchResponse
Sourceimpl JsonSchema for ColumnSizeBatchResponse
impl JsonSchema for ColumnSizeBatchResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ColumnSizeBatchResponse
impl RefUnwindSafe for ColumnSizeBatchResponse
impl Send for ColumnSizeBatchResponse
impl Sync for ColumnSizeBatchResponse
impl Unpin for ColumnSizeBatchResponse
impl UnwindSafe for ColumnSizeBatchResponse