pub struct ColumnSizeOp {
pub target: ColumnTarget,
pub size: ColumnSizeSpec,
}Fields
target: ColumnTargetsize: ColumnSizeSpecTrait Implementations
Sourceimpl Clone for ColumnSizeOp
impl Clone for ColumnSizeOp
Sourcefn clone(&self) -> ColumnSizeOp
fn clone(&self) -> ColumnSizeOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColumnSizeOp
impl Debug for ColumnSizeOp
Sourceimpl<'de> Deserialize<'de> for ColumnSizeOp
impl<'de> Deserialize<'de> for ColumnSizeOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ColumnSizeOp> for ColumnSizeOpInput
impl From<ColumnSizeOp> for ColumnSizeOpInput
Sourcefn from(value: ColumnSizeOp) -> Self
fn from(value: ColumnSizeOp) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ColumnSizeOp
impl JsonSchema for ColumnSizeOp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ColumnSizeOp
impl RefUnwindSafe for ColumnSizeOp
impl Send for ColumnSizeOp
impl Sync for ColumnSizeOp
impl Unpin for ColumnSizeOp
impl UnwindSafe for ColumnSizeOp