pub struct CreateForkParams {
pub workbook_or_fork_id: WorkbookId,
}Fields
workbook_or_fork_id: WorkbookIdTrait Implementations
Sourceimpl Debug for CreateForkParams
impl Debug for CreateForkParams
Sourceimpl<'de> Deserialize<'de> for CreateForkParams
impl<'de> Deserialize<'de> for CreateForkParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateForkParams
impl JsonSchema for CreateForkParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateForkParams
impl RefUnwindSafe for CreateForkParams
impl Send for CreateForkParams
impl Sync for CreateForkParams
impl Unpin for CreateForkParams
impl UnwindSafe for CreateForkParams