pub struct CreateForkResponse {
pub fork_id: String,
pub base_workbook: String,
pub client_base_workbook: Option<String>,
pub ttl_seconds: u64,
}Fields
fork_id: Stringbase_workbook: Stringclient_base_workbook: Option<String>ttl_seconds: u64Trait Implementations
Sourceimpl Debug for CreateForkResponse
impl Debug for CreateForkResponse
Sourceimpl JsonSchema for CreateForkResponse
impl JsonSchema for CreateForkResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateForkResponse
impl RefUnwindSafe for CreateForkResponse
impl Send for CreateForkResponse
impl Sync for CreateForkResponse
impl Unpin for CreateForkResponse
impl UnwindSafe for CreateForkResponse