pub struct DeleteCheckpointResponse {
pub fork_id: String,
pub checkpoint_id: String,
pub deleted: bool,
}Fields
fork_id: Stringcheckpoint_id: Stringdeleted: boolTrait Implementations
Sourceimpl Debug for DeleteCheckpointResponse
impl Debug for DeleteCheckpointResponse
Sourceimpl JsonSchema for DeleteCheckpointResponse
impl JsonSchema for DeleteCheckpointResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteCheckpointResponse
impl RefUnwindSafe for DeleteCheckpointResponse
impl Send for DeleteCheckpointResponse
impl Sync for DeleteCheckpointResponse
impl Unpin for DeleteCheckpointResponse
impl UnwindSafe for DeleteCheckpointResponse