pub struct DiscardForkParams {
pub fork_id: String,
}Fields
fork_id: StringTrait Implementations
Sourceimpl Debug for DiscardForkParams
impl Debug for DiscardForkParams
Sourceimpl<'de> Deserialize<'de> for DiscardForkParams
impl<'de> Deserialize<'de> for DiscardForkParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiscardForkParams
impl JsonSchema for DiscardForkParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscardForkParams
impl RefUnwindSafe for DiscardForkParams
impl Send for DiscardForkParams
impl Sync for DiscardForkParams
impl Unpin for DiscardForkParams
impl UnwindSafe for DiscardForkParams