pub struct DiscardForkResponse {
pub fork_id: String,
pub discarded: bool,
}Fields
fork_id: Stringdiscarded: boolTrait Implementations
Sourceimpl Debug for DiscardForkResponse
impl Debug for DiscardForkResponse
Sourceimpl JsonSchema for DiscardForkResponse
impl JsonSchema for DiscardForkResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscardForkResponse
impl RefUnwindSafe for DiscardForkResponse
impl Send for DiscardForkResponse
impl Sync for DiscardForkResponse
impl Unpin for DiscardForkResponse
impl UnwindSafe for DiscardForkResponse