pub struct DiscardStagedChangeResponse {
pub fork_id: String,
pub change_id: String,
pub discarded: bool,
}Fields
fork_id: Stringchange_id: Stringdiscarded: boolTrait Implementations
Sourceimpl Debug for DiscardStagedChangeResponse
impl Debug for DiscardStagedChangeResponse
Sourceimpl JsonSchema for DiscardStagedChangeResponse
impl JsonSchema for DiscardStagedChangeResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscardStagedChangeResponse
impl RefUnwindSafe for DiscardStagedChangeResponse
impl Send for DiscardStagedChangeResponse
impl Sync for DiscardStagedChangeResponse
impl Unpin for DiscardStagedChangeResponse
impl UnwindSafe for DiscardStagedChangeResponse