pub struct EditBatchResponse {
pub fork_id: String,
pub edits_applied: usize,
pub total_edits: usize,
pub recalc_needed: bool,
pub warnings: Vec<Warning>,
}Fields
fork_id: Stringedits_applied: usizetotal_edits: usizerecalc_needed: boolwarnings: Vec<Warning>Trait Implementations
Sourceimpl Debug for EditBatchResponse
impl Debug for EditBatchResponse
Sourceimpl JsonSchema for EditBatchResponse
impl JsonSchema for EditBatchResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EditBatchResponse
impl RefUnwindSafe for EditBatchResponse
impl Send for EditBatchResponse
impl Sync for EditBatchResponse
impl Unpin for EditBatchResponse
impl UnwindSafe for EditBatchResponse