pub struct EditRecord {
pub timestamp: String,
pub sheet: String,
pub address: String,
pub value: String,
pub is_formula: bool,
}Fields
timestamp: Stringsheet: Stringaddress: Stringvalue: Stringis_formula: boolTrait Implementations
Sourceimpl Debug for EditRecord
impl Debug for EditRecord
Sourceimpl JsonSchema for EditRecord
impl JsonSchema for EditRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EditRecord
impl RefUnwindSafe for EditRecord
impl Send for EditRecord
impl Sync for EditRecord
impl Unpin for EditRecord
impl UnwindSafe for EditRecord