pub struct ForkSummary {
pub fork_id: String,
pub base_path: String,
pub client_base_path: Option<String>,
pub age_seconds: u64,
pub edit_count: usize,
pub recalc_needed: bool,
}Fields
fork_id: Stringbase_path: Stringclient_base_path: Option<String>age_seconds: u64edit_count: usizerecalc_needed: boolTrait Implementations
Sourceimpl Debug for ForkSummary
impl Debug for ForkSummary
Sourceimpl JsonSchema for ForkSummary
impl JsonSchema for ForkSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForkSummary
impl RefUnwindSafe for ForkSummary
impl Send for ForkSummary
impl Sync for ForkSummary
impl Unpin for ForkSummary
impl UnwindSafe for ForkSummary