pub struct GetChangesetResponse {
pub fork_id: String,
pub base_workbook: String,
pub client_base_workbook: Option<String>,
pub changes: Vec<Change>,
pub summary: ChangesetSummary,
}Fields
fork_id: Stringbase_workbook: Stringclient_base_workbook: Option<String>changes: Vec<Change>summary: ChangesetSummaryTrait Implementations
Sourceimpl Debug for GetChangesetResponse
impl Debug for GetChangesetResponse
Sourceimpl JsonSchema for GetChangesetResponse
impl JsonSchema for GetChangesetResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for GetChangesetResponse
impl Serialize for GetChangesetResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more