pub struct GetEditsParams {
pub fork_id: String,
}Fields
fork_id: StringTrait Implementations
Sourceimpl Debug for GetEditsParams
impl Debug for GetEditsParams
Sourceimpl<'de> Deserialize<'de> for GetEditsParams
impl<'de> Deserialize<'de> for GetEditsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetEditsParams
impl JsonSchema for GetEditsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetEditsParams
impl RefUnwindSafe for GetEditsParams
impl Send for GetEditsParams
impl Sync for GetEditsParams
impl Unpin for GetEditsParams
impl UnwindSafe for GetEditsParams