pub struct GridImportResponse {
pub fork_id: String,
pub mode: String,
pub change_id: Option<String>,
pub summary: ChangeSummary,
pub formula_parse_diagnostics: Option<FormulaParseDiagnostics>,
}Fields
fork_id: Stringmode: Stringchange_id: Option<String>summary: ChangeSummaryformula_parse_diagnostics: Option<FormulaParseDiagnostics>Trait Implementations
Sourceimpl Debug for GridImportResponse
impl Debug for GridImportResponse
Sourceimpl JsonSchema for GridImportResponse
impl JsonSchema for GridImportResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for GridImportResponse
impl Serialize for GridImportResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more