pub struct ListCheckpointsResponse {
pub fork_id: String,
pub checkpoints: Vec<CheckpointInfo>,
}Fields
fork_id: Stringcheckpoints: Vec<CheckpointInfo>Trait Implementations
Sourceimpl Debug for ListCheckpointsResponse
impl Debug for ListCheckpointsResponse
Sourceimpl JsonSchema for ListCheckpointsResponse
impl JsonSchema for ListCheckpointsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListCheckpointsResponse
impl RefUnwindSafe for ListCheckpointsResponse
impl Send for ListCheckpointsResponse
impl Sync for ListCheckpointsResponse
impl Unpin for ListCheckpointsResponse
impl UnwindSafe for ListCheckpointsResponse