pub struct ListForksParams {}Trait Implementations
Sourceimpl Debug for ListForksParams
impl Debug for ListForksParams
Sourceimpl<'de> Deserialize<'de> for ListForksParams
impl<'de> Deserialize<'de> for ListForksParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListForksParams
impl JsonSchema for ListForksParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListForksParams
impl RefUnwindSafe for ListForksParams
impl Send for ListForksParams
impl Sync for ListForksParams
impl Unpin for ListForksParams
impl UnwindSafe for ListForksParams