pub struct ListForksResponse {
pub forks: Vec<ForkSummary>,
}Fields
forks: Vec<ForkSummary>Trait Implementations
Sourceimpl Debug for ListForksResponse
impl Debug for ListForksResponse
Sourceimpl JsonSchema for ListForksResponse
impl JsonSchema for ListForksResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListForksResponse
impl RefUnwindSafe for ListForksResponse
impl Send for ListForksResponse
impl Sync for ListForksResponse
impl Unpin for ListForksResponse
impl UnwindSafe for ListForksResponse