pub struct RecalculateResponse {
pub fork_id: String,
pub duration_ms: u64,
pub backend: String,
pub cells_evaluated: Option<u64>,
pub eval_errors: Option<Vec<String>>,
}Fields
fork_id: Stringduration_ms: u64backend: Stringcells_evaluated: Option<u64>eval_errors: Option<Vec<String>>Trait Implementations
Sourceimpl Debug for RecalculateResponse
impl Debug for RecalculateResponse
Sourceimpl JsonSchema for RecalculateResponse
impl JsonSchema for RecalculateResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecalculateResponse
impl RefUnwindSafe for RecalculateResponse
impl Send for RecalculateResponse
impl Sync for RecalculateResponse
impl Unpin for RecalculateResponse
impl UnwindSafe for RecalculateResponse