pub struct RestoreCheckpointParams {
pub fork_id: String,
pub checkpoint_id: String,
}Fields
fork_id: Stringcheckpoint_id: StringTrait Implementations
Sourceimpl Debug for RestoreCheckpointParams
impl Debug for RestoreCheckpointParams
Sourceimpl<'de> Deserialize<'de> for RestoreCheckpointParams
impl<'de> Deserialize<'de> for RestoreCheckpointParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RestoreCheckpointParams
impl JsonSchema for RestoreCheckpointParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RestoreCheckpointParams
impl RefUnwindSafe for RestoreCheckpointParams
impl Send for RestoreCheckpointParams
impl Sync for RestoreCheckpointParams
impl Unpin for RestoreCheckpointParams
impl UnwindSafe for RestoreCheckpointParams