pub struct RestoreCheckpointResponse {
pub fork_id: String,
pub restored_checkpoint: CheckpointInfo,
}Fields
fork_id: Stringrestored_checkpoint: CheckpointInfoTrait Implementations
Sourceimpl Debug for RestoreCheckpointResponse
impl Debug for RestoreCheckpointResponse
Sourceimpl JsonSchema for RestoreCheckpointResponse
impl JsonSchema for RestoreCheckpointResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RestoreCheckpointResponse
impl RefUnwindSafe for RestoreCheckpointResponse
impl Send for RestoreCheckpointResponse
impl Sync for RestoreCheckpointResponse
impl Unpin for RestoreCheckpointResponse
impl UnwindSafe for RestoreCheckpointResponse