pub struct SaveForkResponse {
pub fork_id: String,
pub saved_to: String,
pub client_saved_to: Option<String>,
pub fork_dropped: bool,
}Fields
fork_id: Stringsaved_to: Stringclient_saved_to: Option<String>fork_dropped: boolTrait Implementations
Sourceimpl Debug for SaveForkResponse
impl Debug for SaveForkResponse
Sourceimpl JsonSchema for SaveForkResponse
impl JsonSchema for SaveForkResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SaveForkResponse
impl RefUnwindSafe for SaveForkResponse
impl Send for SaveForkResponse
impl Sync for SaveForkResponse
impl Unpin for SaveForkResponse
impl UnwindSafe for SaveForkResponse