pub struct StructureBatchParams {
pub fork_id: String,
pub ops: Vec<StructureOp>,
pub mode: Option<BatchMode>,
pub label: Option<String>,
pub formula_parse_policy: Option<FormulaParsePolicy>,
pub impact_report: Option<bool>,
pub show_formula_delta: Option<bool>,
}Fields
fork_id: Stringops: Vec<StructureOp>mode: Option<BatchMode>label: Option<String>formula_parse_policy: Option<FormulaParsePolicy>impact_report: Option<bool>show_formula_delta: Option<bool>Trait Implementations
Sourceimpl Debug for StructureBatchParams
impl Debug for StructureBatchParams
Sourceimpl<'de> Deserialize<'de> for StructureBatchParams
impl<'de> Deserialize<'de> for StructureBatchParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StructureBatchParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StructureBatchParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructureBatchParams
impl JsonSchema for StructureBatchParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructureBatchParams
impl RefUnwindSafe for StructureBatchParams
impl Send for StructureBatchParams
impl Sync for StructureBatchParams
impl Unpin for StructureBatchParams
impl UnsafeUnpin for StructureBatchParams
impl UnwindSafe for StructureBatchParams