pub struct StructureBatchResponse {
pub fork_id: String,
pub mode: String,
pub change_id: Option<String>,
pub ops_applied: usize,
pub summary: ChangeSummary,
}Fields
fork_id: Stringmode: Stringchange_id: Option<String>ops_applied: usizesummary: ChangeSummaryTrait Implementations
Sourceimpl Debug for StructureBatchResponse
impl Debug for StructureBatchResponse
Sourceimpl JsonSchema for StructureBatchResponse
impl JsonSchema for StructureBatchResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructureBatchResponse
impl RefUnwindSafe for StructureBatchResponse
impl Send for StructureBatchResponse
impl Sync for StructureBatchResponse
impl Unpin for StructureBatchResponse
impl UnwindSafe for StructureBatchResponse