pub struct StyleBatchResponse {
pub fork_id: String,
pub mode: String,
pub change_id: Option<String>,
pub ops_applied: usize,
pub summary: ChangeSummary,
}Fields
fork_id: Stringmode: Stringchange_id: Option<String>ops_applied: usizesummary: ChangeSummaryTrait Implementations
Sourceimpl Debug for StyleBatchResponse
impl Debug for StyleBatchResponse
Sourceimpl JsonSchema for StyleBatchResponse
impl JsonSchema for StyleBatchResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StyleBatchResponse
impl RefUnwindSafe for StyleBatchResponse
impl Send for StyleBatchResponse
impl Sync for StyleBatchResponse
impl Unpin for StyleBatchResponse
impl UnwindSafe for StyleBatchResponse