pub struct ConditionalFormatStyleSpec {
pub fill_color: Option<String>,
pub font_color: Option<String>,
pub bold: Option<bool>,
}Fields
fill_color: Option<String>font_color: Option<String>bold: Option<bool>Trait Implementations
Sourceimpl Clone for ConditionalFormatStyleSpec
impl Clone for ConditionalFormatStyleSpec
Sourcefn clone(&self) -> ConditionalFormatStyleSpec
fn clone(&self) -> ConditionalFormatStyleSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionalFormatStyleSpec
impl Debug for ConditionalFormatStyleSpec
Sourceimpl Default for ConditionalFormatStyleSpec
impl Default for ConditionalFormatStyleSpec
Sourcefn default() -> ConditionalFormatStyleSpec
fn default() -> ConditionalFormatStyleSpec
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConditionalFormatStyleSpec
impl<'de> Deserialize<'de> for ConditionalFormatStyleSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConditionalFormatStyleSpec
impl JsonSchema for ConditionalFormatStyleSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConditionalFormatStyleSpec
impl RefUnwindSafe for ConditionalFormatStyleSpec
impl Send for ConditionalFormatStyleSpec
impl Sync for ConditionalFormatStyleSpec
impl Unpin for ConditionalFormatStyleSpec
impl UnwindSafe for ConditionalFormatStyleSpec