pub struct RulesBatchParams {
pub fork_id: String,
pub ops: Vec<RulesOp>,
pub mode: Option<BatchMode>,
pub label: Option<String>,
}Fields
fork_id: Stringops: Vec<RulesOp>mode: Option<BatchMode>label: Option<String>Trait Implementations
Sourceimpl Debug for RulesBatchParams
impl Debug for RulesBatchParams
Sourceimpl<'de> Deserialize<'de> for RulesBatchParams
impl<'de> Deserialize<'de> for RulesBatchParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RulesBatchParams
impl JsonSchema for RulesBatchParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RulesBatchParams
impl RefUnwindSafe for RulesBatchParams
impl Send for RulesBatchParams
impl Sync for RulesBatchParams
impl Unpin for RulesBatchParams
impl UnwindSafe for RulesBatchParams