pub struct SheetLayoutBatchResponse {
pub fork_id: String,
pub mode: String,
pub change_id: Option<String>,
pub ops_applied: usize,
pub summary: ChangeSummary,
}Fields
fork_id: Stringmode: Stringchange_id: Option<String>ops_applied: usizesummary: ChangeSummaryTrait Implementations
Sourceimpl Debug for SheetLayoutBatchResponse
impl Debug for SheetLayoutBatchResponse
Sourceimpl JsonSchema for SheetLayoutBatchResponse
impl JsonSchema for SheetLayoutBatchResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SheetLayoutBatchResponse
impl RefUnwindSafe for SheetLayoutBatchResponse
impl Send for SheetLayoutBatchResponse
impl Sync for SheetLayoutBatchResponse
impl Unpin for SheetLayoutBatchResponse
impl UnwindSafe for SheetLayoutBatchResponse