pub struct CloseWorkbookParams {
pub workbook_or_fork_id: WorkbookId,
}Fields
workbook_or_fork_id: WorkbookIdTrait Implementations
Sourceimpl Debug for CloseWorkbookParams
impl Debug for CloseWorkbookParams
Sourceimpl<'de> Deserialize<'de> for CloseWorkbookParams
impl<'de> Deserialize<'de> for CloseWorkbookParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CloseWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CloseWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CloseWorkbookParams
impl JsonSchema for CloseWorkbookParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CloseWorkbookParams
impl RefUnwindSafe for CloseWorkbookParams
impl Send for CloseWorkbookParams
impl Sync for CloseWorkbookParams
impl Unpin for CloseWorkbookParams
impl UnsafeUnpin for CloseWorkbookParams
impl UnwindSafe for CloseWorkbookParams