pub struct DescribeWorkbookParams {
pub workbook_or_fork_id: WorkbookId,
}Fields
workbook_or_fork_id: WorkbookIdTrait Implementations
Sourceimpl Debug for DescribeWorkbookParams
impl Debug for DescribeWorkbookParams
Sourceimpl<'de> Deserialize<'de> for DescribeWorkbookParams
impl<'de> Deserialize<'de> for DescribeWorkbookParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DescribeWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DescribeWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DescribeWorkbookParams
impl JsonSchema for DescribeWorkbookParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DescribeWorkbookParams
impl RefUnwindSafe for DescribeWorkbookParams
impl Send for DescribeWorkbookParams
impl Sync for DescribeWorkbookParams
impl Unpin for DescribeWorkbookParams
impl UnsafeUnpin for DescribeWorkbookParams
impl UnwindSafe for DescribeWorkbookParams