pub struct VerifyWorkbookParams {
pub baseline_workbook_or_fork_id: WorkbookId,
pub current_workbook_or_fork_id: WorkbookId,
pub targets: Vec<String>,
pub sheet_name: Option<String>,
pub include_named_range_deltas: bool,
pub errors_only: bool,
pub targets_only: bool,
}Fields
baseline_workbook_or_fork_id: WorkbookIdcurrent_workbook_or_fork_id: WorkbookIdtargets: Vec<String>sheet_name: Option<String>include_named_range_deltas: boolerrors_only: booltargets_only: boolTrait Implementations
Sourceimpl Debug for VerifyWorkbookParams
impl Debug for VerifyWorkbookParams
Sourceimpl<'de> Deserialize<'de> for VerifyWorkbookParams
impl<'de> Deserialize<'de> for VerifyWorkbookParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifyWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifyWorkbookParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifyWorkbookParams
impl JsonSchema for VerifyWorkbookParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VerifyWorkbookParams
impl RefUnwindSafe for VerifyWorkbookParams
impl Send for VerifyWorkbookParams
impl Sync for VerifyWorkbookParams
impl Unpin for VerifyWorkbookParams
impl UnsafeUnpin for VerifyWorkbookParams
impl UnwindSafe for VerifyWorkbookParams