pub struct VbaProjectSummaryParams {
pub workbook_or_fork_id: WorkbookId,
pub max_modules: Option<u32>,
pub include_references: Option<bool>,
}Fields
workbook_or_fork_id: WorkbookIdmax_modules: Option<u32>include_references: Option<bool>Trait Implementations
Sourceimpl Debug for VbaProjectSummaryParams
impl Debug for VbaProjectSummaryParams
Sourceimpl<'de> Deserialize<'de> for VbaProjectSummaryParams
impl<'de> Deserialize<'de> for VbaProjectSummaryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VbaProjectSummaryParams
impl JsonSchema for VbaProjectSummaryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VbaProjectSummaryParams
impl RefUnwindSafe for VbaProjectSummaryParams
impl Send for VbaProjectSummaryParams
impl Sync for VbaProjectSummaryParams
impl Unpin for VbaProjectSummaryParams
impl UnwindSafe for VbaProjectSummaryParams