pub struct EditBatchParamsInput {
pub fork_id: String,
pub sheet_name: String,
pub edits: Vec<CellEditInput>,
}Fields
fork_id: Stringsheet_name: Stringedits: Vec<CellEditInput>Trait Implementations
Sourceimpl Clone for EditBatchParamsInput
impl Clone for EditBatchParamsInput
Sourcefn clone(&self) -> EditBatchParamsInput
fn clone(&self) -> EditBatchParamsInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EditBatchParamsInput
impl Debug for EditBatchParamsInput
Sourceimpl<'de> Deserialize<'de> for EditBatchParamsInput
impl<'de> Deserialize<'de> for EditBatchParamsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EditBatchParamsInput
impl JsonSchema for EditBatchParamsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EditBatchParamsInput
impl RefUnwindSafe for EditBatchParamsInput
impl Send for EditBatchParamsInput
impl Sync for EditBatchParamsInput
impl Unpin for EditBatchParamsInput
impl UnwindSafe for EditBatchParamsInput