pub struct DataValidationSpec {
pub kind: DataValidationKind,
pub formula1: String,
pub formula2: Option<String>,
pub allow_blank: Option<bool>,
pub prompt: Option<ValidationMessage>,
pub error: Option<ValidationMessage>,
}Fields
kind: DataValidationKindformula1: Stringformula2: Option<String>allow_blank: Option<bool>prompt: Option<ValidationMessage>error: Option<ValidationMessage>Trait Implementations
Sourceimpl Clone for DataValidationSpec
impl Clone for DataValidationSpec
Sourcefn clone(&self) -> DataValidationSpec
fn clone(&self) -> DataValidationSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataValidationSpec
impl Debug for DataValidationSpec
Sourceimpl<'de> Deserialize<'de> for DataValidationSpec
impl<'de> Deserialize<'de> for DataValidationSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DataValidationSpec
impl JsonSchema for DataValidationSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DataValidationSpec
impl RefUnwindSafe for DataValidationSpec
impl Send for DataValidationSpec
impl Sync for DataValidationSpec
impl Unpin for DataValidationSpec
impl UnwindSafe for DataValidationSpec